@@ -14,10 +14,12 @@ c    2015-12-28 RBS: Changed the version to 4.2
 c    2017-02-08 RBS: Changed the version to 4.2.3
 c    2017-09-19 RBS: Changed the version to 4.2.6
 c    2018-06-13 RBS: Changed the version to 4.2.7
+c    2018-07-17 RBS: Changed the version to 4.2.9_beta
+c    2018-07-24 RBS: Changed the version to 4.3
 c
 c Character strings for SCREAMER version.
 c Edit this string as version changes
 c
       character*(*) screamer_version
       parameter (screamer_version =
-     & 'SCREAMER v4.2.7.1')
+     & 'SCREAMER v4.3')
